/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.prediction.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Insert2.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Prediction API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Insert2 extends GenericJson {

  /**
   * Insert time of the model (as a RFC 3339 timestamp).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime created;

  /**
   * The unique name for the predictive model.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * What kind of resource this is.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Model metadata.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ModelInfo modelInfo;

  /**
   * Type of predictive model (CLASSIFICATION or REGRESSION).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String modelType;

  /**
   * A URL to re-request this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * Google storage location of the training data file.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String storageDataLocation;

  /**
   * Google storage location of the preprocessing pmml file.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String storagePMMLLocation;

  /**
   * Google storage location of the pmml model file.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String storagePMMLModelLocation;

  /**
   * Training completion time (as a RFC 3339 timestamp).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime trainingComplete;

  /**
   * The current status of the training job. This can be one of following: RUNNING; DONE; ERROR;
   * ERROR: TRAINING JOB NOT FOUND
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String trainingStatus;

  /**
   * Insert time of the model (as a RFC 3339 timestamp).
   * The value returned may be {@code null}.
   */
  public DateTime getCreated() {
    return created;
  }

  /**
   * Insert time of the model (as a RFC 3339 timestamp).
   * The value set may be {@code null}.
   */
  public Insert2 setCreated(DateTime created) {
    this.created = created;
    return this;
  }

  /**
   * The unique name for the predictive model.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The unique name for the predictive model.
   * The value set may be {@code null}.
   */
  public Insert2 setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * What kind of resource this is.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * What kind of resource this is.
   * The value set may be {@code null}.
   */
  public Insert2 setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Model metadata.
   * The value returned may be {@code null}.
   */
  public ModelInfo getModelInfo() {
    return modelInfo;
  }

  /**
   * Model metadata.
   * The value set may be {@code null}.
   */
  public Insert2 setModelInfo(ModelInfo modelInfo) {
    this.modelInfo = modelInfo;
    return this;
  }

  /**
   * Type of predictive model (CLASSIFICATION or REGRESSION).
   * The value returned may be {@code null}.
   */
  public String getModelType() {
    return modelType;
  }

  /**
   * Type of predictive model (CLASSIFICATION or REGRESSION).
   * The value set may be {@code null}.
   */
  public Insert2 setModelType(String modelType) {
    this.modelType = modelType;
    return this;
  }

  /**
   * A URL to re-request this resource.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * A URL to re-request this resource.
   * The value set may be {@code null}.
   */
  public Insert2 setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Google storage location of the training data file.
   * The value returned may be {@code null}.
   */
  public String getStorageDataLocation() {
    return storageDataLocation;
  }

  /**
   * Google storage location of the training data file.
   * The value set may be {@code null}.
   */
  public Insert2 setStorageDataLocation(String storageDataLocation) {
    this.storageDataLocation = storageDataLocation;
    return this;
  }

  /**
   * Google storage location of the preprocessing pmml file.
   * The value returned may be {@code null}.
   */
  public String getStoragePMMLLocation() {
    return storagePMMLLocation;
  }

  /**
   * Google storage location of the preprocessing pmml file.
   * The value set may be {@code null}.
   */
  public Insert2 setStoragePMMLLocation(String storagePMMLLocation) {
    this.storagePMMLLocation = storagePMMLLocation;
    return this;
  }

  /**
   * Google storage location of the pmml model file.
   * The value returned may be {@code null}.
   */
  public String getStoragePMMLModelLocation() {
    return storagePMMLModelLocation;
  }

  /**
   * Google storage location of the pmml model file.
   * The value set may be {@code null}.
   */
  public Insert2 setStoragePMMLModelLocation(String storagePMMLModelLocation) {
    this.storagePMMLModelLocation = storagePMMLModelLocation;
    return this;
  }

  /**
   * Training completion time (as a RFC 3339 timestamp).
   * The value returned may be {@code null}.
   */
  public DateTime getTrainingComplete() {
    return trainingComplete;
  }

  /**
   * Training completion time (as a RFC 3339 timestamp).
   * The value set may be {@code null}.
   */
  public Insert2 setTrainingComplete(DateTime trainingComplete) {
    this.trainingComplete = trainingComplete;
    return this;
  }

  /**
   * The current status of the training job. This can be one of following: RUNNING; DONE; ERROR;
   * ERROR: TRAINING JOB NOT FOUND
   * The value returned may be {@code null}.
   */
  public String getTrainingStatus() {
    return trainingStatus;
  }

  /**
   * The current status of the training job. This can be one of following: RUNNING; DONE; ERROR;
   * ERROR: TRAINING JOB NOT FOUND
   * The value set may be {@code null}.
   */
  public Insert2 setTrainingStatus(String trainingStatus) {
    this.trainingStatus = trainingStatus;
    return this;
  }

  /**
   * Model metadata.
   */
  public static final class ModelInfo extends GenericJson {

    /**
     * Estimated accuracy of model taking utility weights into account (Categorical models only).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String classWeightedAccuracy;

    /**
     * A number between 0.0 and 1.0, where 1.0 is 100% accurate. This is an estimate, based on the
     * amount and quality of the training data, of the estimated prediction accuracy. You can use this
     * is a guide to decide whether the results are accurate enough for your needs. This estimate will
     * be more reliable if your real input data is similar to your training data (Categorical models
     * only).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String classificationAccuracy;

    /**
     * An estimated mean squared error. The can be used to measure the quality of the predicted model
     * (Regression models only).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String meanSquaredError;

    /**
     * Type of predictive model (CLASSIFICATION or REGRESSION).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String modelType;

    /**
     * Number of valid data instances used in the trained model.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long numberInstances;

    /**
     * Number of class labels in the trained model (Categorical models only).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long numberLabels;

    /**
     * Estimated accuracy of model taking utility weights into account (Categorical models only).
     * The value returned may be {@code null}.
     */
    public String getClassWeightedAccuracy() {
      return classWeightedAccuracy;
    }

    /**
     * Estimated accuracy of model taking utility weights into account (Categorical models only).
     * The value set may be {@code null}.
     */
    public ModelInfo setClassWeightedAccuracy(String classWeightedAccuracy) {
      this.classWeightedAccuracy = classWeightedAccuracy;
      return this;
    }

    /**
     * A number between 0.0 and 1.0, where 1.0 is 100% accurate. This is an estimate, based on the
     * amount and quality of the training data, of the estimated prediction accuracy. You can use this
     * is a guide to decide whether the results are accurate enough for your needs. This estimate will
     * be more reliable if your real input data is similar to your training data (Categorical models
     * only).
     * The value returned may be {@code null}.
     */
    public String getClassificationAccuracy() {
      return classificationAccuracy;
    }

    /**
     * A number between 0.0 and 1.0, where 1.0 is 100% accurate. This is an estimate, based on the
     * amount and quality of the training data, of the estimated prediction accuracy. You can use this
     * is a guide to decide whether the results are accurate enough for your needs. This estimate will
     * be more reliable if your real input data is similar to your training data (Categorical models
     * only).
     * The value set may be {@code null}.
     */
    public ModelInfo setClassificationAccuracy(String classificationAccuracy) {
      this.classificationAccuracy = classificationAccuracy;
      return this;
    }

    /**
     * An estimated mean squared error. The can be used to measure the quality of the predicted model
     * (Regression models only).
     * The value returned may be {@code null}.
     */
    public String getMeanSquaredError() {
      return meanSquaredError;
    }

    /**
     * An estimated mean squared error. The can be used to measure the quality of the predicted model
     * (Regression models only).
     * The value set may be {@code null}.
     */
    public ModelInfo setMeanSquaredError(String meanSquaredError) {
      this.meanSquaredError = meanSquaredError;
      return this;
    }

    /**
     * Type of predictive model (CLASSIFICATION or REGRESSION).
     * The value returned may be {@code null}.
     */
    public String getModelType() {
      return modelType;
    }

    /**
     * Type of predictive model (CLASSIFICATION or REGRESSION).
     * The value set may be {@code null}.
     */
    public ModelInfo setModelType(String modelType) {
      this.modelType = modelType;
      return this;
    }

    /**
     * Number of valid data instances used in the trained model.
     * The value returned may be {@code null}.
     */
    public Long getNumberInstances() {
      return numberInstances;
    }

    /**
     * Number of valid data instances used in the trained model.
     * The value set may be {@code null}.
     */
    public ModelInfo setNumberInstances(Long numberInstances) {
      this.numberInstances = numberInstances;
      return this;
    }

    /**
     * Number of class labels in the trained model (Categorical models only).
     * The value returned may be {@code null}.
     */
    public Long getNumberLabels() {
      return numberLabels;
    }

    /**
     * Number of class labels in the trained model (Categorical models only).
     * The value set may be {@code null}.
     */
    public ModelInfo setNumberLabels(Long numberLabels) {
      this.numberLabels = numberLabels;
      return this;
    }

  }

}
